"""
Title     : Command line module
Objective : execute scraping operation com command lines
Created by: Abdellah Janid
Created on: 6/3/20
"""
# Standard library imports

# Related third party imports
import click

from scraper import GoScraping
# Import local applications
from scraper import init_directories, init_configuration
from scraper.list import ListManagement
from scraper.session import ScraperSession

targets = ['people',
           'my_followers',
           'my_connections',
           'employees',
           'group_members',
           'companies',
           'schools',
           'jobs_list',
           'jobs',
           'mutual_connections',
           'connections_in_org'
           ]

source = ['people',
          'my_followers',
          'my_connections',
          'employees',
          'group_members',
          'companies',
          'schools',
          'jobs_list',
          'jobs',
          'mutual_connections',
          'connections_in_org'
          ]

data_to_add = ['people',
               'my_followers',
               'my_connections',
               'employees',
               'group_members',
               'companies',
               'similar_companies',
               'schools',
               'jobs_list',
               'jobs',
               'mutual_connections',
               'connections_in_org',
               'mutual_connections_url',
               'experience',
               'education',
               'certifications',
               'volunteering',
               'received_recommendations',
               'given_recommendations',
               'publications_collaborators',
               'patents_collaborators',
               'projects_collaborators',
               'people_also_viewed',
               'jobs_poster',
               'similar_jobs'
               ]

folders = ["data", "watchdog"]
method = ["all", "selected"]
browser_commands = ["open", "quit"]


@click.command()
@click.option('--config', type=click.Choice(["init"]),
              help='Creates brobygger_li folder, and shows where it has been created.')
@click.option('--scrape', type=click.Choice(targets),
              help='Meant for production. Scrape links from the list defined in the configuration.'
                   'eg,"GoScraping --scrape people" will scrape people profiles defined in people_links_list.csv.')
@click.option('--test', type=click.Choice(targets),
              help='Tests that the scraping is okay by scraping a known profile and validating the results.')
@click.option('--browser', type=click.Choice(browser_commands),
              help='Open or close the browser.')
@click.option('--from_source', default=[None] * 2, type=click.Tuple([click.Choice(source), click.Choice(folders)]),
              help='Source from which add data eg: --from_source  companies data --add all employees --to employees data')
@click.option('--add', default=[None] * 2, type=click.Tuple([click.Choice(method), click.Choice(data_to_add)]),
              help='method: all or selected and the data to add. eg: all employees')
@click.option('--to', default=[None] * 2, type=click.Tuple([click.Choice(targets), click.Choice(folders)]),
              help='Target to which add data eg: employees data')
def cli_commands(config, scrape, test, browser, from_source, add, to):
    """A scraping program to get data from Linkedin."""
    # TODO auto completion
    if config == "init":
        wd = init_directories()
        click.echo("Initialized directories in : " + str(wd))
    # Scrape
    if scrape:
        click.echo("scraping " + scrape)
        go = GoScraping(scrape, "data")
        go.scraping()

    if test:
        click.echo("testing " + test)
        go = GoScraping(test, "watchdog")
        go.scraping()

    if browser == "open":
        click.echo("Opening browser")
        config = init_configuration("free_browsing")
        session = ScraperSession(config, "free_browsing", "watchdog")
        while True:
            command = input('type "quit" in the terminal to close the browser : ')
            if command == "quit":
                session.driver.quit()
                break

    if all(from_source) and all(add) and all(to):
        source_cm, folder_source_cm = from_source
        method_cm, data_from_source = add
        target_cm, folder_target_cm = to

        click.echo("Adding data: from {} {} add {} {} to {} {}".format(source_cm, folder_source_cm,
                                                                       method_cm, data_from_source,
                                                                       target_cm, folder_target_cm))

        list_management = ListManagement(from_source, add, to)
        list_management.add(list_management.method)

    # if all(add):
    #     method_cm, data_from_source = add
    #
    #     if data_from_source == "employees":
    #         source_cm, folder_source_cm = "employees" , "data"
    #         method_cm, data_from_source = add
    #         target_cm, folder_target_cm = "people", "data"
    #         click.echo("Adding data: from {} {} add {} {} to {} {}".format(source_cm, folder_source_cm,
    #                                                                        method_cm, data_from_source,
    #                                                                        target_cm, folder_target_cm))
    #
    #         list_management = ListManagement(from_source, add, to)
    #         list_management.add(list_management.method)

if __name__ == '__main__':
    cli_commands()
