"""
Title     :
Objective : Exceptions
Created by: Abdellah Janid
Created on: 5/21/20
"""


class ConfigError(Exception):
    """Thrown when checking that the profile is login has failed"""
    pass


class LinksListError(ValueError):
    """Thrown when the the links list fails validation"""

    def __init__(self, *args):
        super(LinksListError, self).__init__(*args)

    def __str__(self):
        return "%s" % (super(LinksListError, self).__str__())


class SessionException(Exception):
    """Base class for exceptions raised by Session module."""
    pass


class ElementException(SessionException):
    """Exception raised for errors in the input."""

    def __init__(self, method=None, selector=None, url=None):
        """

        Parameters
        ----------
        method : str
            By selector type selenium.webdriver.common.by.By
        selector : str
            selector to look for
        url : str
            url on which the exception is raised
        """
        self.method = method
        self.selector = selector
        self.url = url

    def __str__(self):
        return "method: %s, selector: %s, url: %s" % (self.method, self.selector, self.url)


class UserBoxNotFound(ElementException):
    """Thrown when the user box is not found"""
    pass


class PasswordBoxNotFound(ElementException):
    """Thrown when the password box is not found"""
    pass


class FailedCheckLogin(ElementException):
    """Thrown when checking that the profile is login has failed"""

    def __init__(self, method=None, selector=None, url=None, condition=None):
        super(FailedCheckLogin, self).__init__(method, selector, url)
        self.condition = condition

    def __str__(self):
        return "%s, condition: %s" % (super(FailedCheckLogin, self).__str__(), self.condition)


class UrlError(ValueError):
    """Thrown when the the linkedin link is not valid"""

    def __init__(self, *args):
        super(UrlError, self).__init__(*args)

    def __str__(self):
        return "%s" % (super(UrlError, self).__str__())


class InvalidUrlError(UrlError):
    """Thrown when the the linkedin link is not valid"""
    pass


class UrlNotAvailable(UrlError):
    """Thrown when the the linkedin link is not valid"""
    pass
