"""
Html elaboration
"""
import json
import re
from pathlib import Path
from bs4 import BeautifulSoup
from datetime import datetime


def get_meta_data(file_path):
    """Get meta data
    Parameters
    ----------
    file_path : PosixPath
        name of the key to add meta data
    Returns
    -------
    """
    with file_path.open('r') as fp:
        p = json.load(fp)

    meta_data = p
    return meta_data


# Print iterations progress
def print_progress_bar(iteration, total, prefix='', suffix='', decimals=1, length=100, fill='█', printEnd="\r"):
    """
    Call in a loop to create terminal progress bar

    Parameters
    ----------
    iteration : int
        Current iteration
    total : int
        Total iterations
    prefix : str, optional
        Prefix string
    suffix: str, optional
        Suffix string
    decimals : int, optional
        positive number of decimals in percent complete
    length : int, optional
         character length of bar
    fill : str, optional
        bar fill character
    printEnd : str
        end character
    """
    percent = ("{0:." + str(decimals) + "f}").format(100 * (iteration / float(total)))
    filledLength = int(length * iteration // total)
    bar = fill * filledLength + '-' * (length - filledLength)
    print(f'\r{prefix} |{bar}| {percent}% {suffix} {iteration}/{total}', end=printEnd)
    # Print New Line on Complete
    if iteration == total:
        print()

#**************************************
# Init
#**************************************
# define path to html directory
wd = Path("/home/noonwave/fintech_data_mining/meta_data/test")
#**************************************

html_path = Path(wd, "profiles")

# get the list of paths to profiles
profiles_list = list(Path(html_path).iterdir())
l = len(profiles_list)

start = datetime.now()
print("start: " + str(start))
print_progress_bar(0, l, prefix='Progress:', suffix='Complete', length=50)
for i, p in enumerate(profiles_list):
    html_path_profile = p
    htmls_list = list(Path(html_path_profile).rglob('*.html'))

    data = {}
    data.update({"init": {
        "id": html_path_profile.name.split("_")[0],
        "name": html_path_profile.name
    }})
    meta_data_container = {}
    for j, h in enumerate(htmls_list):
        meta_data = get_meta_data(h)
        if meta_data:
            key = h.name.split("_")[0]
            if not key:
                key = "meta_" + j
            meta_data_container.update({key: meta_data})

    if ("start" in meta_data_container.keys()) and ("end" in meta_data_container.keys()):
        if meta_data_container['start'] == meta_data_container['end']:
            meta_data_container.pop("start")

    data.update({"meta_data_container": meta_data_container})

    file_path = Path(wd, "meta_data", html_path_profile.name + ".json")
    # print("JSON saved in: " + str(file_path))
    with file_path.open("w", encoding='utf-8') as fp:
        json.dump(data, fp)

    Path(html_path_profile).rename(Path(wd, "appended", html_path_profile.name))
    # Update Progress Bar
    print_progress_bar(i + 1, l, prefix='Progress:', suffix='Complete', length=50)

end = datetime.now()
print("start: " + str(end))

