"""
Title     : TODO
Objective : TODO
Created by: Abdellah Janid
Created on: 6/11/20
"""
# Standard library imports
import logging
from pathlib import Path

import pandas as pd
# Related third party imports
from selenium.webdriver.common.by import By

# Import local applications
from scraper.linkedin.group_members import items
from scraper.session import ScraperSession

# Create a module logger
logger_group_members_scraper = logging.getLogger('group_members')
# Set level
logger_group_members_scraper.setLevel(logging.DEBUG)


class GroupMembers(ScraperSession):
    """Contains methods to scrape data on group members
    """

    def get_group_info(self):
        """Get some info about the group being scraped

        Returns
        -------

        """
        self.extra = {}
        group_info = self.select_element(
            method=By.CSS_SELECTOR, selector=".groups-members-list__core-rail",
            return_type="bs_el",
            html_name="group_info",
            html_path=self.html_path_profile,
            screenshot_name="group_info",
            screenshot_path=self.screenshots_path_profile,
        )
        self.extra = items.get_group_info(group_info)
        self.data.update({"extra": self.extra})
        logger_group_members_scraper.debug("session, finished, group_info")
        return self.extra

    def get_group_members(self):
        """

        Returns
        -------

        """
        self.group_members = self.get_data_from_section(
            section="group_members",
            method=By.CSS_SELECTOR, selector=".groups-members-list__core-rail",
            list_method=By.CSS_SELECTOR, list_selector="li.groups-members-list__typeahead-result",
            get_info_function=items.get_group_members_info
        )
        self.data.update({"group_members": self.group_members})
        logger_group_members_scraper.debug("session, finished, group_members")

    def scrape(self):
        """
        Returns
        -------
            data : dict
                see profile data structure for more details

        """
        self.scraping_status = "running"
        self.load_page(By.CSS_SELECTOR, ".groups-members-list__core-rail", By.CSS_SELECTOR, ".not-found",
                       "/members/")

        self.get_group_info()
        self.get_group_members()

        if self.group_members:
            # Saving csv
            df = pd.DataFrame(self.data["group_members"])
            df_shuffled = df.sample(frac=1)
            df_shuffled.to_csv(Path(self.profiles_path, self.file_name + "_" + self.init["timestamp_start"] + ".csv"),
                               index=False, sep=";")
            self.extra_info = self.extra["name"] + " (" + str(self.extra["len"]) + ")"
            logger_group_members_scraper.info("done , " +
                                            " , " +
                                              self.data["init"]["id"] +
                                            " , " +
                                              self.data["init"]["url"])
        else:
            logger_group_members_scraper.info("Failed getting group members")
            raise ValueError("Failed getting employees")
