"""
Title     : TODO
Objective : TODO
Created by: Abdellah Janid
Created on: 6/11/20
"""
# Standard library imports
from typing import Optional, List, Union, Any

# Related third party imports
from pydantic import BaseModel, Field

# Import local applications
from scraper.general_schemas import InitModel, ExtraModel


# noinspection PyMissingOrEmptyDocstring
class JobsTopCardModel(BaseModel):
    title: str = Field(...)
    company: str = Field(...)
    location: str = Field(...)
    posting_date: Optional[str] = Field(...)
    nr_applicants: Optional[str] = Field(...)
    message: Optional[str] = Field(...)
    url_company: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "title": "title",
            "company": "company",
            "location": "location",
            "posting_date": "posting_date",
            "nr_applicants": "nr_applicants",
            "message": "message",
            "url_company": "url_company"
        }
        allow_population_by_field_name = True


# noinspection PyMissingOrEmptyDocstring
class JobsPosterModel(BaseModel):
    full_name: str = Field(...)
    headline: Optional[str] = Field(...)
    location: str = Field(...)
    distance: Optional[str] = Field(...)
    url: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "full_name": "full_name",
            "headline": "headline",
            "location": "location",
            "distance": "distance",
            "url": "url"
        }
        allow_population_by_field_name = True


# noinspection PyMissingOrEmptyDocstring
# class DescriptionDetailsModel(BaseModel):
#     description_titles: List[str] = Field(...)
#     industry: List[str] = Field(...)
#     employment_type: List[str] = Field(...)
#     job_functions: List[str] = Field(...)
#
#     # noinspection PyMissingOrEmptyDocstring
#     class Config:
#         fields = {
#             "description_titles": "description_titles",
#             "industry": "industry",
#             "employment_type": "employment_type",
#             "job_functions": "job_functions"
#         }
#         extra = 'allow'
#         allow_population_by_field_name = True


# noinspection PyMissingOrEmptyDocstring
class TopSkillsModel(BaseModel):
    skill: str = Field(...)
    satisfied: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "skill": "skill",
            "satisfied": "satisfied"
        }
        allow_population_by_field_name = True


# noinspection PyMissingOrEmptyDocstring
class SeniorityLevelModel(BaseModel):
    level: str = Field(...)
    max: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "level": "level",
            "max": "max"
        }
        allow_population_by_field_name = True


# noinspection PyMissingOrEmptyDocstring
class EducationModel(BaseModel):
    num: str = Field(...)
    qualification: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "num": "num",
            "qualification": "qualification"
        }
        allow_population_by_field_name = True


# noinspection PyMissingOrEmptyDocstring
class LocationModel(BaseModel):
    number: str = Field(...)
    location: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "number": "number",
            "location": "location"
        }
        allow_population_by_field_name = True


# noinspection PyMissingOrEmptyDocstring
class SimilarJobsModel(BaseModel):
    title: str = Field(...)
    company: str = Field(...)
    location: str = Field(...)
    posting_date: Optional[str] = Field(...)
    flavors: Optional[str] = Field(...)
    url: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "num": "num",
            "qualification": "qualification"
        }
        allow_population_by_field_name = True


class JobsSchema(BaseModel):
    """
    Job Schema
    """
    init: InitModel = Field(...)
    extra: ExtraModel = Field(...)
    top_card_info: JobsTopCardModel = Field(...)
    jobs_poster: Union[dict, JobsPosterModel] = Field(...)
    description_details: Any = Field(...)
    description: str = Field(...)
    applicant_rank: Optional[dict] = Field(...)
    top_skills: List[TopSkillsModel] = Field(...)
    seniority_level: List[SeniorityLevelModel] = Field(...)
    education: List[EducationModel] = Field(...)
    location: List[LocationModel] = Field(...)
    similar_jobs: List[SimilarJobsModel] = Field(...)
    more_similar_jobs: Optional[str] = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        title = 'Jobs'
        fields = {
            'init': 'init',
            "extra": "extra",
            'top_card_info': 'info',
            'jobs_poster': 'jobs_poster',
            'description_details': 'description_details',
            'description': 'description',
            'applicant_rank': 'applicant_rank',
            'top_skills': 'top_skills',
            'seniority_level': 'seniority_level',
            'education': 'education',
            'location': 'location',
            'similar_jobs': 'similar_jobs',
            'more_similar_jobs': 'more_similar_jobs'

        }
        extra = 'allow'
        allow_population_by_field_name = True
