"""
Title     : TODO
Objective : Get jobs_list info
Created by: Abdellah Janid
Created on: 5/26/20
"""
# Standard library imports


# Related third party imports
from bs4 import BeautifulSoup

# Import local applications
from scraper import scraping_tools as mt


def get_job_info(soup: BeautifulSoup):
    """
    Get list of jobs_list short description
    Returns
    -------
    info : dict
        a list of dictionaries with the following {keys: values}
        title       : str
            Job title
        dist_value      : str, default None
            The distance to the person.
        headline        : str, default None
            headline title.
        location        : str, default None
            The location of the person.
        connections     : str, default None
            The connections the person has on linkedin.
    """
    info = mt.get_info(soup, {
        "title": "a.job-card-list__title",
        "company": "a.job-card-container__company-name",
        "actively_recruiting": ".job-card-list__insight",
        "nr_applicants": ".job-card-container__applicant-count",
        "location": "li.job-card-container__metadata-item",
    })
    # info["meta_data"] = soup.select(".job-card-container__metadata-wrapper li.job-card-container__metadata-item")

    info["connections_in_org"] = mt.get_attribute_value(soup, "a.search-s-shared-connections__link", "href")
    if info['connections_in_org'] is not None:
        info['connections_in_org'] = "https://www.linkedin.com" + info['connections_in_org']

    if info['actively_recruiting']:
        if "Actively recruiting" in info['actively_recruiting']:
            info['actively_recruiting'] = True
        else:
            info['actively_recruiting'] = False

    info["url_job"] = mt.get_attribute_value(soup, "a.job-card-list__title", "href")
    if info['url_job'] is not None:
        info['url_job'] = "https://www.linkedin.com" + info['url_job']

    info["url_company"] = mt.get_attribute_value(soup, "a.job-card-container__company-name", "href")
    if info['url_company'] is not None:
        info['url_company'] = "https://www.linkedin.com" + info['url_company']

    info["posting_date"] = mt.get_attribute_value(soup, "li.job-card-container__listed-time time", "datetime")

    return info
