"""
Title     : Jobs
Objective : Scrape data from linkedin's link of jobs_list search
Created by: Janid
Created on: 5/25/20
"""

# Standard library imports
import logging

# Related third party imports
from selenium.webdriver.common.by import By

# Import local applications
from scraper import scraping_tools as mt
from scraper.linkedin.jobs_list import items
from scraper.session import ScraperSession

# Create a module logger
logger_jobs_list_scraper = logging.getLogger('jobs_scraper')
# Set level
logger_jobs_list_scraper.setLevel(logging.DEBUG)


class JobsList(ScraperSession):
    """Contains the tools to scrape data on a jobs_list from a link on linkedin"""

    def get_last_page(self):
        """
        Get the number of the last page
        """
        last_page = self.select_element(By.CSS_SELECTOR,
                                        'ul.artdeco-pagination__pages--number '
                                        'li.artdeco-pagination__indicator--number:last-child',
                                        return_type="bs_el")
        if last_page:
            last_page = int(mt.get_text(last_page, "span"))
        else:
            last_page = 0
        return last_page

    def get_jobs_from_page(self):
        """ Get jobs list from a page
        """
        logger_jobs_list_scraper.debug("session, started, getting data from one page")
        self.jobs_list = []
        # Scroll to the bottom of the page
        scroll = self.select_elements(By.CSS_SELECTOR,
                                      'ul.jobs-search-results__list li.jobs-search-results__list-item',
                                      return_type="sel_el")
        for j in range(0, len(scroll), 2):
            scroll[j].location_once_scrolled_into_view
            self.driver.implicitly_wait(2)


        # Save the source page
        mt.save_html(self.driver.page_source, self.html_path_profile, "jobs_list")

        jobs_list = self.select_elements(By.CSS_SELECTOR,
                                         'ul.jobs-search-results__list li.jobs-search-results__list-item',
                                         return_type="bs_el")
        self.jobs_list.extend([items.get_job_info(j) for j in jobs_list])
        self.get_meta_data("page_0")

    def get_jobs_list(self):
        """
        Get the list of jobs_list posted
        Returns
        -------

        """
        # Init jobs_list container
        self.jobs_list = []
        logger_jobs_list_scraper.debug("session, started, jobs_list")
        # How many pages are there
        last_page = self.get_last_page()

        if last_page:
            # Loop over pages
            for i in range(last_page):
                # Save the source page
                logger_jobs_list_scraper.debug("getting page {}".format(i+1))
                # Click on the next page
                self.click_on(By.CSS_SELECTOR,
                              'li.artdeco-pagination__indicator[data-test-pagination-page-btn="{}"]'.format(i+1))

                self.select_element(By.CSS_SELECTOR,
                              'li.artdeco-pagination__indicator.active[data-test-pagination-page-btn="{}"]'.format(i+1))

                # Scroll to the bottom of the page
                scroll = self.select_elements(By.CSS_SELECTOR,
                                                 'ul.jobs-search-results__list li.jobs-search-results__list-item',
                                                 return_type="sel_el")
                for j in range(0, len(scroll), 3):
                    scroll[j].location_once_scrolled_into_view
                    mt.random_rest(1,2)

                mt.save_html(self.driver.page_source, self.html_path_profile, "jobs_list_" + str(i + 1))




                jobs_list = self.select_elements(By.CSS_SELECTOR,
                                                 'ul.jobs-search-results__list li.jobs-search-results__list-item',
                                                 return_type="bs_el")

                self.jobs_list.extend([items.get_job_info(j) for j in jobs_list])
                self.get_meta_data("page_"+str(i+1))

        else:
            self.get_jobs_from_page()

        self.extra = {
            "name": "jobs_list",
            "len": len(self.jobs_list),
            "tag": None,
            "added": None,
            "other": None
        }
        self.data.update({"extra": self.extra})
        self.data.update({"jobs_list": self.jobs_list})

    def scrape(self):
        """
        Returns
        -------
            data : dict
                see profile data structure for more details

        """
        # Define the status
        self.scraping_status = "running"

        # Load the profile
        self.load_page(By.CSS_SELECTOR, ".job-search-ext", By.CSS_SELECTOR, ".not-found", "/jobs/")
        self.get_jobs_list()

        self.scraping_status = "completed"
