"""
Title     : Jobs
Objective : Scrape data from linkedin's link of jobs_list search
Created by: Janid
Created on: 5/25/20
"""

# Standard library imports
import logging

# Related third party imports
from selenium.webdriver.common.by import By

# Import local applications
from scraper import scraping_tools as mt
from scraper.linkedin.jobs import items
from scraper.session import ScraperSession

# Create a module logger
logger_learn_scraper = logging.getLogger('learn')
# Set level
logger_learn_scraper.setLevel(logging.DEBUG)


class Learn(ScraperSession):
    """Contains the tools to scrape data on a jobs from a link on linkedin"""

    def get_quiz(self):
        """
        Get the top card
        """
        logger_learn_scraper.debug("session, started, quiz")
        self.quiz = {}
        # Select top-card: pv-top-card
        quiz_el = self.scroll_select(By.CSS_SELECTOR, 'div.exam-question',
                                      return_type="bs_el",
                                      html_name="quiz",
                                      html_path=self.html_path_profile,
                                      screenshot_name="quiz",
                                      screenshot_path=self.screenshots_path_profile,
                                      )
        # get top card info
        self.quiz = items.get_quiz(quiz_el)
        self.data.update({"quiz": self.quiz})

        logger_learn_scraper.debug("session, finished, quiz")

    def scrape(self):
        """
        Returns
        -------
            data : dict
                see profile data structure for more details

        """
        # Define the status
        self.scraping_status = "running"
        # Load the profile
        self.load_page(By.CSS_SELECTOR, ".job-view-layout", By.CSS_SELECTOR, ".not-found", "/learning/")

        self.scraping_status = "completed"
