"""
Title     : TODO
Objective : TODO
Created by: Abdellah Janid
Created on: 6/2/20
"""

# Standard library imports
import logging
from pathlib import Path

import pandas as pd
# Related third party imports
from selenium.webdriver.common.by import By

# Import local applications
from scraper.linkedin.my_connections import items
from scraper.session import ScraperSession

# Create a module logger
logger_connections_scraper = logging.getLogger('connections_scraper')
# Set level
logger_connections_scraper.setLevel(logging.DEBUG)


class MyConnections(ScraperSession):
    """Contains the tools to scrape data your followers from
    https://www.linkedin.com/mynetwork/invite-connect/connections/"""

    def scrape(self):
        """
        Returns
        -------
            data : dict
                see profile data structure for more details

        """
        self.scraping_status = "running"
        # # Get the number of expected elements, a security to make sure the page if fully loaded
        # header = self.select_element(method=By.CSS_SELECTOR, selector="header.mn-connections__headerh",
        #                              return_type="bs_el")
        # nr = items.get_expected_els(header)["nr"]
        # if nr is None:
        #     raise ValueError("Failed getting my connections nr is None")

        self.load_page(By.CSS_SELECTOR, "section.mn-connections", By.CSS_SELECTOR, ".not-found", "/mynetwork/")

        connections = self.select_elements(By.CSS_SELECTOR, 'li.mn-connection-card', return_type="bs_el")
        self.extra = {
            "name": "my_connections",
            "len": len(connections),
            "tag": None,
            "added": None,
            "other": None
        }
        self.data.update({"extra": self.extra})
        if connections:
            self.info = list(map(items.get_my_connections, connections))
            self.data.update({"my_connections": self.info})
            df = pd.DataFrame(self.data["my_connections"])
            df_shuffled = df.sample(frac=1)
            df_shuffled.to_csv(Path(self.profiles_path, "my_connections_" + self.init["timestamp_start"] + ".csv"),
                               index=False, sep=";")
            self.get_meta_data('end')
            logger_connections_scraper.debug("Getting my connections done")
            self.scraping_status = "completed"

        else:
            logger_connections_scraper.debug("Getting my connections  Error")
            self.scraping_status = "failed"
            raise ValueError("Failed getting my connections")
