"""
Title     : TODO
Objective : TODO
Created by: Abdellah Janid
Created on: 6/2/20
"""

# Standard library imports
import logging
from pathlib import Path

# Related third party imports
import pandas as pd
from selenium.webdriver.common.by import By

# Import local applications
from scraper.linkedin.my_followers import items
from scraper.session import ScraperSession

# Create a module logger
logger_followers_scraper = logging.getLogger('followers_scraper')
# Set level
logger_followers_scraper.setLevel(logging.DEBUG)


class MyFollowers(ScraperSession):
    """Contains the tools to scrape data your followers from https://www.linkedin.com/feed/followers/"""

    def scrape(self):
        """
        Returns
        -------
            data : dict
                see profile data structure for more details

        """
        self.scraping_status = "running"
        self.load_page(By.CSS_SELECTOR, ".feed-following", By.CSS_SELECTOR, ".not-found", "/feed/")

        followers = self.select_elements(By.CSS_SELECTOR, 'li.follows-recommendation-card', return_type="bs_el")
        self.extra = {
            "name": "my_followers",
            "len": len(followers),
            "tag": None,
            "added": None,
            "other": None
        }
        self.data.update({"extra": self.extra})
        if followers:
            self.info = list(map(items.get_my_followers, followers))
            self.data.update({"my_followers": self.info})
            df = pd.DataFrame(self.data["my_followers"])
            df_shuffled = df.sample(frac=1)
            df_shuffled.to_csv(Path(self.profiles_path, "my_followers_" + self.init["timestamp_start"] + ".csv"),
                               index=False,
                               sep=";")
            self.get_meta_data('end')
            logger_followers_scraper.debug("Getting Followers done")
            self.scraping_status = "completed"

        else:
            logger_followers_scraper.debug("Getting Followers Error")
            self.scraping_status = "failed"
            raise ValueError("Failed getting my followers")
