import json
from pathlib import Path
import logging
from datetime import datetime
from scraper.scraping_tools import save_json
from scraper.validation_tools import validate_schema
from scraper.linkedin.rename.schema import LiPersonAllModel
from scraper.linkedin.people.schemas import LiPersonAllModel as PeopleAllSchema


def init_logger(data_path):
    """Set up the logger

    Parameters
    ----------
    data_path : str
        Path to folder to save log events
    """

    if logging.getLogger().hasHandlers():
        logging.getLogger().handlers.clear()

    # Setting up the logger configurations
    timestamp = datetime.now().strftime("%d_%m_%y_(%H_%M_%S)")
    log_filename = timestamp + ".log"  # set the name of logging file

    logging.basicConfig(filename=Path(data_path, log_filename),
                        filemode="a",
                        level=logging.INFO,
                        format='%(levelname)-12s , %(asctime)s , %(name)-12s , %(message)s',
                        datefmt='%d/%m/%y %H:%M:%S')

    # define a Handler which writes INFO messages or higher to the sys.stderr
    console = logging.StreamHandler()
    # set level to DEBUG if you want to see DEBUG info into the console
    console.setLevel(logging.DEBUG)
    # set a format which is simpler for console use
    formatter = logging.Formatter('%(levelname)-12s , %(asctime)s , %(name)-12s , %(message)s')
    # tell the handler to use this format
    console.setFormatter(formatter)
    # add the handler to the root logger
    logging.getLogger('').addHandler(console)


data_path = "/home/noonwave/Documents/GitHub/Thesis_Fintech/02_Code/sna_complete_version_not otto/"

# Init logger
init_logger(data_path)

# Rename the folders if profiles is empty
profiles = list(Path(data_path, "profiles").rglob('*.json'))
if not profiles:
    print("Renaming the folders")  # a hack to quickly transfer the data to profiles folder
    Path(data_path, "appended").rename(Path(data_path, "c"))
    Path(data_path, "profiles").rename(Path(data_path, "appended"))
    Path(data_path, "c").rename(Path(data_path, "profiles"))

# Get json files path
profiles = list(Path(data_path, "profiles").rglob('*.json'))
# Print how many files have been found
print("Total number of profiles to load: {}".format(len(profiles)))

# Init an empty list of nodes
# N = []
# Load profiles to list of Nodes N
for profile in profiles:
    try:
        with profile.open('r') as p:
            d = json.load(p)
            # N.append(d)
            # Validate the data-----
            data = validate_schema(LiPersonAllModel,
                                   d,
                                   Path(data_path, "failed"), d["init"]["id"])
            # Save the data---------
            save_json(json.loads(data.json(by_alias=True)),
                      Path(data_path, "renamed"),
                      profile.name)
            # ---------------------
            Path(profile).rename(Path(data_path, "appended", profile.name))
            logging.debug("appended:" + str(profile.name))

    except:
        Path(profile).rename(Path(data_path, "failed", profile.name))
        logging.debug("failed:" + str(profile.name))

# print("Total number of profiles loaded: {}".format(len(N)))
#
# S = []
# for p in N:
#     if p["summary"] and ("see more" in p["summary"]):
#         S.append(p)
# Find dupplicates
N = [p.name.split("_")[0] for p in profiles]

D = set([x for x in N if N.count(x) > 1])