"""
Title     : Schemas for company json
Objective : Validate the data
Created by: Abdellah Janid
Created on: 6/21/20
"""
# Standard library imports
from typing import Optional

# Related third party imports
from pydantic import BaseModel, Field

# Import local applications
from scraper.general_schemas import InitModel, ExtraModel


# noinspection PyMissingOrEmptyDocstring
class SchoolsModel(BaseModel):
    name: str = Field(...)
    tagline: Optional[str] = Field(...)
    location: Optional[str] = Field(...)
    alumni: Optional[str] = Field(...)
    followers: Optional[int] = Field(...)
    employees_on_li: Optional[int] = Field(...)
    connections_in_org: Optional[str] = Field(...)
    website: Optional[str] = Field(...)
    url_connections_in_org: Optional[str] = Field(...)
    url_employees: str = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        fields = {
            "name": "name",
            "tagline": "tagline",
            "location": "location",
            "alumni": "alumni",
            'followers': 'followers',
            'employees_on_li': 'employees_on_li',
            'connections_in_org': 'connections_in_org',
            'website': 'website',
            'url_connections_in_org': 'url_connections_in_org',
            "url_employees": "url_employees"
        }
        allow_population_by_field_name = True


class SchoolsSchema(BaseModel):
    """
    Companies Schema
    """
    init: InitModel = Field(...)
    top_card_info: SchoolsModel = Field(...)
    extra: ExtraModel = Field(...)

    # noinspection PyMissingOrEmptyDocstring
    class Config:
        title = 'Schools'
        fields = {
            'init': 'init',
            'top_card_info': 'top_card_info',
            'extra': 'extra'

        }
        extra = 'allow'

        allow_population_by_field_name = True
